# Terms

Terms are the building blocks of GAM models. Each term represents a different way of including variables in your model, from simple linear effects to complex multidimensional smooth functions. If you are familiar with ``mgcv``, then the mgcv representation of the term can be inspected for any term using ``str(term)``.


::: pymgcv.terms.L
::: pymgcv.terms.S
::: pymgcv.terms.T
::: pymgcv.terms.Interaction
::: pymgcv.terms.Offset
::: pymgcv.terms.Intercept
